#
# spec file for package mutt
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with    mutt_openssl
%bcond_without mutt_gnutls

Name:           mutt
%if %{with mutt_openssl}
BuildRequires:  pkgconfig(openssl)
%endif
%if %{with mutt_gnutls}
BuildRequires:  pkgconfig(gnutls)
%endif
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cyrus-sasl-gssapi
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  hunspell
BuildRequires:  iso_ent
BuildRequires:  libgpgme-devel
BuildRequires:  libxslt-tools
BuildRequires:  opensp
BuildRequires:  pkgconfig(gssrpc)
BuildRequires:  pkgconfig(krb5)
%if 0%{?suse_version} > 1315
BuildRequires:  pkgconfig(kyotocabinet)
%else
BuildRequires:  libkyotocabinet-devel
%endif
%if 0%{?suse_version} > 1315
BuildRequires:  pkgconfig(libidn2)
%else
BuildRequires:  pkgconfig(libidn)
%endif
BuildRequires:  pkgconfig(libsasl2)
%if 0%{?suse_version} > 1315
BuildRequires:  pkgconfig(ncurses)
%else
BuildRequires:  ncurses-devel
%endif
%if 0%{?suse_version} > 1130
BuildRequires:  pkgconfig(shared-mime-info)
%endif
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
BuildRequires:  w3m
Url:            http://www.mutt.org
Recommends:     hunspell
Provides:       muttssl
Obsoletes:      muttssl
Recommends:     mutt-doc
Recommends:     mutt-lang
Recommends:     urlscan
Recommends:     urlview
Recommends:     w3m
%if 0%{?suse_version} > 1130
Requires(post):   shared-mime-info
Requires(postun): shared-mime-info
%endif
Version:        1.10.1
Release:        lp151.2.12.1
Summary:        Mail Program
# ftp://ftp.mutt.org/mutt/devel/
# https:///bitbucket.org/mutt/mutt/downloads/%%name-%%version.tar.gz
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Email/Clients
Source0:        https://bitbucket.org/mutt/mutt/downloads/mutt-%version.tar.gz
Source1:        Signature_conversion
Source2:        README.alternates
Source3:        mutt.png
Source4:        mutt.desktop
Source5:        skel.muttrc
Source9:        mutt.mailcap
Patch:          %name-1.10.0.dif
# http://www.spinnaker.de/mutt/compressed/
Patch2:         %name-1.5.9i-pgpewrap.diff
Patch3:         %name-1.5.20-sendgroupreplyto.diff
Patch4:         %name-1.5.15-wrapcolumn.diff
Patch7:         mutt-1.6.1-opennfs.dif
Patch9:         bug-676388-largefile.patch
# http://www.wolfermann.org/mutt.html
Patch11:        aw.listreply.diff
Patch12:        patch-1.5.24.vk.pgp_verbose_mime
# PATCH-FIX-OPENSUSE: bnc#813498 - mutt crashes in fgetwc in text_enriched_handler
Patch15:        widechar.sidebar.dif
# PATCH-FIX-OPENSUSE: Be able to read signed/encrypted messsages even with CRLF
Patch16:        mutt-1.5.23-carriage-return.path
# PATCH-FIX-OPENSUSE bnc#899712 - fallback mailcap for e.g text/html
Patch18:        mutt-1.5.21-mailcap.diff
# PATCH-FIX-SUSE: bsc#907453 - CVE-2014-9116: mutt: heap-based buffer overflow in mutt_substrdup()
Patch19:        bsc907453-CVE-2014-9116-jessie.patch
# PATCH-FIX-SUSE: Silent gcc about truncated buffer with snprintf()
Patch20:        truncate.patch
Patch21:        3e88866dc60b5fa6aaba6fd7c1710c12c1c3cd01.patch
Patch22:        mutt-1.10.1-backport-mutt_ssl_gnutls-1.14.3.dif
Patch23:        c547433cdf2e79191b15c6932c57f1472bfb5ff4.dif
Patch24:        CVE-2020-28896.patch
Patch25:        nofreeze-c72f740a.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%global         _sysconfdir %{_sysconfdir}

%description
A very powerful mail user agent. It supports (among other nice things)
highlighting, threading, and PGP. It takes some time to get used to,
however. This version is based on NeoMutt, that is it includes many
enhancements.

%package doc
Summary:        Additional Documentation about Mutt
Group:          Documentation/Other
Requires:       %{name} = %{version}
Recommends:     perl(Expect)
Provides:       %{name}:%{_docdir}/%name/COPYRIGHT
BuildArch:      noarch

%description doc
Some extend documentation about mutt together with muttrc examples
for different environments and requirements.

%package lang
Summary:        Languages for Mutt
Group:          System/Localization
Provides:       mutt:/usr/share/locale/en_GB/LC_MESSAGES/mutt.mo
Requires:       %{name} = %{version}
BuildArch:      noarch

%description lang
Provides translations to the package mutt.

%prep
%setup -q -D -n mutt-%version
%patch -p0 -b .p0
%patch2 -p0 -b .pgpewrap
%patch3 -p0 -b .sendgroupreplyto
%patch4 -p0 -b .wrapcolumn
%patch7 -p0 -b .opennfs
%patch9 -p0 -b .largefile
%patch11 -p0 -b .listreply
%patch12 -p0 -b .pgp_verbose_mtime
%patch15 -p0 -b .widechar.sidebar
%patch16 -p0 -b .crlf
%patch18 -p0 -b .mailcap
%patch19 -p0 -b .cvw2014.9116
%patch20 -p0 -b .trc
%patch21 -p0 -b .p21
%patch22 -p0 -b .p22
%patch23 -p0 -b .p23
%patch24 -p0 -b .p24
%patch25 -p0 -b .p25

cp %{S:2} .

%build
%if %{with mutt_gnutls}
echo 'set ssl_ca_certificates_file="/etc/ssl/ca-bundle.pem"' >> doc/Muttrc.head
%endif
autoreconf -fi
  cflags ()
  {
    local flag=$1; shift
    local var=$1; shift
    test -n "${flag}" -a -n "${var}" || return
    case "${!var}" in
    *${flag}*) return
    esac
    set -o noclobber
    case "$flag" in
    -Wl,*)
	if echo 'int main () { return 0; }' | \
	    ${CC:-gcc} -Werror $flag -o /dev/null -xc - > /dev/null 2>&1 ; then
	    eval $var=\${$var:+\$$var\ }$flag
	fi
	;;
    *)
	if ${CC:-gcc} -Werror $flag -S -o /dev/null -xc /dev/null > /dev/null 2>&1 ; then
	    eval $var=\${$var:+\$$var\ }$flag
	fi
    esac
    set +o noclobber
  }
CC=gcc
CFLAGS="-Wall $RPM_OPT_FLAGS -I. -D_GNU_SOURCE"
cflags -fno-strict-aliasing		CFLAGS
cflags -fstack-protector		CFLAGS
cflags -fPIE				CFLAGS
cflags -g3				CFLAGS
cflags -pipe				CFLAGS
cflags -Wl,--as-needed			LDFLAGS
cflags -Wl,-O2				LDFLAGS
cflags -pie				LDFLAGS
export CC CFLAGS LDFLAGS
export SENDMAIL=/usr/sbin/sendmail
export ISPELL=/usr/bin/hunspell
export PATH="/usr/lib/mit/bin:$PATH"
export KRB5CFGPATH="$(type -p krb5-config)"
$KRB5CFGPATH --cflags gssapi
$KRB5CFGPATH --libs gssapi
$KRB5CFGPATH --version
%configure \
	--with-docdir=%{_docdir}/%name \
%if %{with mutt_openssl}
	--without-gnutls \
	--with-ssl=%{_prefix} \
%endif
%if %{with mutt_gnutls}
	--without-ssl \
	--with-gnutls=%{_prefix} \
%endif
	--enable-imap \
	--enable-pop \
	--enable-pgp \
	--enable-gpgme \
	--enable-nfs-fix \
	--enable-mailtool \
	--enable-compressed \
	--enable-sidebar \
	--disable-external-dotlock \
	--with-kyotocabinet \
	--with-sasl=%{_prefix} \
	--with-gss=%{_prefix} \
	--with-curses=%{_prefix} \
	--enable-smtp \
	--enable-hcache \
	--with-regex \
%if 0%{?suse_version} > 1315
	--with-idn2
%else
	--with-idn
%endif
make -C doc clean
make
make -C doc

%install
make install DESTDIR=%{buildroot}
install -m 755 %{S:1} %{buildroot}%{_bindir}
gzip -n -9 doc/manu*.txt
rm -f contrib/Makefile*
# datadir not automatically created:
mkdir -p %{buildroot}%{_datadir}/mutt
# INSTALL file should be removed:
rm -rf %{buildroot}%{_docdir}/%{name}/INSTALL
# mbox/mmdf manual page conflicts with the one from tin, so rename it
mv %{buildroot}%{_mandir}/man5/mbox.5 \
   %{buildroot}%{_mandir}/man5/mbox_mutt.5
mv %{buildroot}%{_mandir}/man5/mmdf.5 \
   %{buildroot}%{_mandir}/man5/mmdf_mutt.5
   %find_lang %name
# We get mime.types from aaa_base
rm -f %{buildroot}%{_sysconfdir}/mime.types
# Mutt BTS is gone
rm -f %{buildroot}%{_mandir}/man1/{flea*,muttbug*}
rm -f %{buildroot}%{_bindir}/{flea,muttbug}
rm -f %{buildroot}%{_sysconfdir}/Muttrc.dist
rm -f %{buildroot}%{_sysconfdir}/mime.types.dist
mkdir -p %{buildroot}%{_datadir}/pixmaps
install -m 644 %{SOURCE3} %{buildroot}%{_datadir}/pixmaps/
mkdir -p %{buildroot}%{_datadir}/applications
install -m 644 %{SOURCE4} %{buildroot}%{_datadir}/applications/
install -D -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/skel/.muttrc
install -D -m 644 %{SOURCE9} %{buildroot}%{_datadir}/%name/mailcap
rm -vf %{buildroot}%{_docdir}/%name/manual.txt
install -D -m 644 doc/manual.txt.gz %{buildroot}%{_docdir}/%name/
%if 0%{?suse_version}
%suse_update_desktop_file mutt
%endif

%if 0%{?suse_version} > 1130
%post
%mime_database_post

%postun
%mime_database_postun
%endif

%files
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/skel/.muttrc
%config(noreplace) %{_sysconfdir}/Muttrc
%{_bindir}/mutt
%{_bindir}/pgpewrap
%{_bindir}/pgpring
%{_bindir}/smime_keys
%{_bindir}/Signature_conversion
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/mutt.png
%{_mandir}/man1/mutt.1.gz
%{_mandir}/man1/pgp*.1.gz
%{_mandir}/man1/smime_keys.1.gz
%{_mandir}/man5/mmdf_mutt.5.gz
%{_mandir}/man5/muttrc.5.gz
%{_mandir}/man5/mbox_mutt.5.gz
%dir %{_datadir}/mutt/
%{_datadir}/mutt/mailcap
%dir %doc %{_docdir}/%name/
%doc %{_docdir}/%name/manual.txt.gz

%files doc
%defattr(-,root,root)
%doc %{_docdir}/%name/COPYRIGHT
%doc %{_docdir}/%name/ChangeLog
%doc %{_docdir}/%name/GPL
%doc %{_docdir}/%name/NEWS
%doc %{_docdir}/%name/README*
%doc %{_docdir}/%name/TODO
%doc %{_docdir}/%name/*.html
%doc %{_docdir}/%name/*.txt
%dir %doc %{_docdir}/%name/samples/
%doc %{_docdir}/%name/samples/*.rc
%doc %{_docdir}/%name/samples/ca-bundle.crt
%doc %{_docdir}/%name/samples/colors.*
%doc %{_docdir}/%name/samples/mutt_xtitle
%doc %{_docdir}/%name/samples/sample.*
%doc %{_docdir}/%name/samples/smime_keys_test.pl
%dir %doc %{_docdir}/%name/samples/iconv/
%doc %{_docdir}/%name/samples/iconv/*.rc

%files lang -f %name.lang
%defattr(-,root,root)

%changelog
* Tue Dec  8 2020 Dr. Werner Fink <werner@suse.de>
- Add a further correction in patch nofreeze-c72f740a.patch for
  external bodies as well (boo#1179461)
* Wed Dec  2 2020 Dr. Werner Fink <werner@suse.de>
- Correct patch nofreeze-c72f740a.patch
  * that is also decrease recurse_level counter on leave of the
    counting functions (boo#1179461)
* Wed Nov 25 2020 Dr. Werner Fink <werner@suse.de>
- Add patch nofreeze-c72f740a.patch
  * Avoid that message with a million tiny parts can freeze MUA
    for several minutes (bsc#1179113)
* Mon Nov 23 2020 Dr. Werner Fink <werner@suse.de>
- Add patch CVE-2020-28896.patch to fix bsc#1179035
  * incomplete connection termination could lead to sending
    credentials over unencrypted connections
* Wed Jun 24 2020 Dr. Werner Fink <werner@suse.de>
- Add patch c547433cdf2e79191b15c6932c57f1472bfb5ff4.dif (bsc#1173197)
  * Fix CVE-2020-14954: STARTTLS buffering issue allowing man
    in the middle attack of IMAP, SMTP and POP3
* Wed Jun 24 2020 Dr. Werner Fink <werner@suse.de>
- Repair patch mutt-1.10.1-backport-mutt_ssl_gnutls-1.14.3.dif
  * do not remove reseting messages buffer `priority`
* Fri Jun 19 2020 Dr. Werner Fink <werner@suse.de>
- Fix boo#1172906, boo#1172935, CVE-2020-14093, CVE-2020-14154
  * Add commit/patch 3e88866dc60b5fa6aaba6fd7c1710c12c1c3cd01.patch
    + Prevent possible IMAP MITM via PREAUTH response.
  * Add patch mutt-1.10.1-backport-mutt_ssl_gnutls-1.14.3.dif
    to port mutt_ssl_gnutls.c from mutt 1.14.3 back
    + expired certs not properly rejected with GnuTLS
    + Side effect is support of TLSv1_3 is supported by gnutls
* Tue Jul 17 2018 werner@suse.de
- Update to mutt 1.10.1 (boo#1101428)
  This is an important bug-fix release, fixing a code injection
  and a couple path traversal vulnerabilities.
  This also covers
  * CVE-2018-14363 bnc#1101566
  * CVE-2018-14362 bnc#1101567
  * CVE-2018-14361 bnc#1101568
  * CVE-2018-14360 bnc#1101569
  * CVE-2018-14359 bnc#1101570
  * CVE-2018-14358 bnc#1101571
  * CVE-2018-14357 bnc#1101573
  * CVE-2018-14356 bnc#1101576
  * CVE-2018-14355 bnc#1101577
  * CVE-2018-14354 bnc#1101578
  * CVE-2018-14353 bnc#1101581
  * CVE-2018-14352 bnc#1101582
  * CVE-2018-14351 bnc#1101583
  * CVE-2018-14350 bnc#1101588
  * CVE-2018-14349 bnc#1101589
- Modified patches
  * bug-676388-largefile.patch
  * mutt-1.5.15-wrapcolumn.diff
  * mutt-1.5.20-sendgroupreplyto.diff
  * mutt-1.5.23-carriage-return.path
  * mutt-1.6.1-opennfs.dif
  * patch-1.5.24.vk.pgp_verbose_mime
  * truncate.patch
* Thu Jul  5 2018 werner@suse.de
- Skip neomutt now (boo#1094717)
  * There exists a package neomutt
  * mutt-1.10.0 uses a lot of extensions now like compessed folders
    and header caching, but still misses things like notmuch
- Modified patches
  * aw.listreply.diff
  * bsc907453-CVE-2014-9116-jessie.patch
  * bug-676388-largefile.patch
  * mutt-1.5.15-wrapcolumn.diff
  * mutt-1.5.20-sendgroupreplyto.diff
  * mutt-1.5.21-mailcap.diff
  * mutt-1.5.23-carriage-return.path
  * mutt-1.5.9i-pgpewrap.diff
  * mutt-1.6.1-opennfs.dif
  * patch-1.5.24.vk.pgp_verbose_mime
  * widechar.sidebar.dif
- Renamed patch: mutt-1.9.1.dif becomes mutt-1.10.0.dif
- Deleted patches mutt-1.9.0-1.9.1.patch neomutt-c030a8b.patch
- Add patch truncate.patch to avoid truncated buffers due snprintf
* Tue Oct 24 2017 werner@suse.de
- Add patch mutt-1.9.0-1.9.1.patch which is a backport of the
  mutt upstream patch diff-1.9.0-1.9.1 to neomutt 20170912
- Rename patch mutt-1.9.0.dif which now becomes mutt-1.9.1.dif
* Wed Oct  4 2017 werner@suse.de
- Add patch neomutt-c030a8b.patch from upstream commit to fix
  boo#1061343
* Fri Sep 15 2017 werner@suse.de
- Update to neomutt 20170912 which updates to mutt 1.9.0
  NeoMutt
    Add guix build support
    Only match real mailboxes when looking for new mail
    Fix the printing of ncurses version in -v output
    Bind editor <delete> to delete-char
    Fix overflowing colours
    Fix empty In-Reply-To generation
    Trim trailing slash from completed dirs
    Add guix-neomutt.scm
    Fix setting custom query_type in notmuch query
    Better curses identification
    Use the system's wchar_t support
    Use the system's md5 tool (or equivalent)
    Clean up configure.ac
    Teach gen-map-doc about the new opcode header
    Rename functions (snake_case)
    Rename constants/defines (UPPER_CASE)
    Create library of shared functions
    Much tidying
    Rename globals to match user config
    Drop unnecessary functions/macros
    Use a standard list implementation
    Coverity fixes
    Use explicit NUL for string terminators
    Drop OPS* in favour of opcodes.h
  Upstream
    Fix menu color calls to occur before positioning the cursor
    When guessing an attachment type, don't allow text/plain if there is a null character
    Add $imap_poll_timeout to allow mailbox polling to time out
    Handle error if REGCOMP in pager fails when resizing
    Change recvattach to allow nested encryption
    Fix attachment check_traditional and extract_keys operations
    Add edit-content-type helper and warning for decrypted attachments
    Add option to run command to query attachment mime type
    Add warning about using inline pgp with format=flowed
- Rename patch mutt-1.8.3.dif which becomes now mutt-1.9.0.dif
- Modify the patches
  * aw.listreply.diff
  * bsc907453-CVE-2014-9116-jessie.patch
  * bug-676388-largefile.patch
  * mutt-1.5.15-wrapcolumn.diff
  * mutt-1.5.20-sendgroupreplyto.diff
  * mutt-1.5.21-mailcap.diff
  * mutt-1.5.23-carriage-return.path
  * mutt-1.5.9i-pgpewrap.diff
  * mutt-1.6.1-opennfs.dif
  * patch-1.5.24.vk.pgp_verbose_mime
  * widechar.sidebar.dif
* Thu Aug 10 2017 tchvatal@suse.com
- Switch to hunspell as default spell-checking software wrt
  fate#323578
- Write SUSE in the skel.muttrc instead of SuSE
- Use the right folder for unpacking instead of symlink
  * fixes quilt setup
* Thu Jul 13 2017 olaf@aepfle.de
- If built with gnutls, set ssl_ca_certificates_file to avoid
  warning about "server cert signed using an insecure algorithm"
* Wed Jul 12 2017 olaf@aepfle.de
- Add buildconditional for openssl/gnutls
  Disable gnutls, there can be only one of them and openssl was used
- Use pkgconfig to refer to openssl/gnutls
- Remove uneeded builddeps and recommends for smtp_daemon by
  specifying the path to sendmail
- Remove uneeded builddep for ispell by specifying the path to it
- Update doc builddeps: add opensp, libxslt-tools, w3m
  drop docbook_4,libxml2,libxslt,lynx,sgml-skel,xli
- Remove unneeded builddeps: fdupes,glibc-i18ndata,libassuan,
  libcom_err,libgcrypt,libgpg-error
- Wrap desktop files handing in suse_version
- Remove included krb5-config, the copy in the devel pkg is good enough
- Use configure macro for ordinary autoconf result
- Build manual.txt with w3m to properly dump tables
- Move Requires perl-Expect to doc pkg, make it a Recommends
- Consistent suse_version for shared-mime-info usage
- Unconditional libgpgme usage
- Unconditional autoreconf
* Tue Jun 13 2017 werner@suse.de
- Update to neomutt 20170609 which updates to mutt 1.8.3
  + Warn on bindkey aliasing
  + Drop PATCHES, tidy 'mutt -v' output
  + Add %%z format strings to index_format
  + Add debug_level/debug_file options
  + Fix nntp group selection
  + Fix status color
  + Tidy up S/MIME contrib
  + Do not try to create Maildir if it is an NNTP URI
  + Fix missing NONULL for mutt.set() in Lua
  + Fix German PGP shortkeys
  + Remove feature muttrc files
  + Merge README.notmuch into manual
  + Remove unneded scripts
  + Remove README.SECURITY
  + Remove BEWARE and devel-notes.txt
  + Update Makefiles
  + Delete TODO files
  + Remove legacy files
  + Don't generate vim-neomutt syntax file
  + Remove LaTeX/pdf manual generation
  + Add missing docs for expandos
  + Fix sidebar howto examples
  + Remove some upstream references
  + Drop refs to patches
  + Improve PR template and CONTRIBUTING.md
  + Fix list items in newbie-tutorial's Mailing List Guidelines
  + Remove configure options that no longer exist
  + fix newbie tutorial
  + document signing tags / releases
  + config: drop unused paginate command
  + script: split tests up into several
  + convert credits page to markdown
  + simpify 404 page
  + improve newbie tutorial
  + remove help.html and integrate its content elsewhere
  + make: "graphviz" program is needed for generating diagram
  + improve getting started guide // include legacy files
  + dev: add list of architectures/operating systems
  + numerous small fixes
  + Remove typedefs and rename ~130 structs
  + Add separate hcache dir
  + Move crypto files to ncrypt dir
  + Split up mutt.h, protos.h
  + Always build: sidebar, imap, pop, smtp, compressed, nntp
  + Remove --enable-mailtool configure option
  + Make dotlock optional
  + Change gpgme requirement back to 1.1.0
  + Remove check_sec.sh
  + Fix safe_calloc args
  + Remove unused macros
  + Remove unused option: SmimeSignOpaqueCommand
  + Move configure-generated files
  + Update distcheck build flags
  + Drop obsolete iconv check
  + Unused prototypes - unsupported systems
  + Drop many configure tests for things defined in POSIX:2001
  + Kill useless crypthash.h file
  + Run clang-format on the code
  + Fail early if ncursesw cannot be found
  + Add names prototype arguments
  + Abbreviate pointer tests against NULL
  + Initialise pointers to NULL
  + Reduce the scope of for loop variables
  + Coverity: fix defects
  + Convert all exec calls to use mutt_envlist(), remove setenv function
  + Note that mbox-hooks are dependent on $move
  + Refresh header color when updating label
  + Remove glibc-specific execvpe() call in sendlib.c
  + Add color commands for the compose menu headers and security status
  + Fix sidebar count updates when closing mailbox
  + Don't modify LastFolder/CurrentFolder upon aborting a change folder operation
  + Change message modifying operations to additively set redraw flags
  + Improve maildir and mh to report flag changes in mx_check_mailbox()
  + Add $header_color_partial to allow partial coloring of headers
  + Rename REDRAW_SIGWINCH to REDRAW_FLOW
  + Create R_PAGER_FLOW config variable flag
  + Turn IMAP_EXPUNGE_EXPECTED back off when syncing
  + Add $history_remove_dups option to remove dups from history ring
  + Also remove duplicates from the history file
  + Don't filter new entries when compacting history save file
  + Move the IMAP msn field to IMAP_HEADER_DATA
  + Fix imap expunge to match msn and fix index
  + Fix cmd_parse_fetch() to match against MSN
  + Start fixing imap_read_headers() to account for MSN gaps
  + Add msn_index and max_msn to find and check boundaries by MSN
  + Properly adjust fetch ranges when handling new mail
  + Small imap fetch fixes
  + Don't abort header cache evaluation when there is a hole
  + Fix mfc overflow check and uninitialized variable
  + Fix potential segv if mx_open_mailbox is passed an empty string
  + Don't clean up idata when closing an open-append mailbox
  + Don't clean up msn idata when closing an open-append mailbox
  + Fix memory leak when closing mailbox and using the sidebar
  + Change imap body cache cleanup to use the uid_hash
  + Convert classic s/mime to space delimit findKeys output
  + Add self-encrypt options for PGP and S/MIME
  + Change $postpone_encrypt to use self-encrypt variables first
  + Automatic post-release commit for mutt-1.8.3
  + Add note about message scoring and thread patterns
  + unbind mappings before overwriting in vim-keys
  + latest coverity issues (#624)
  + don't pass colour-codes to filters
  + Don't set a colour unless it's been defined.
  + crash if no from is set or founds
  + ifdef command
  + fix translations
  + fix some remaining translation problems
  + explain binding warnings
  + don't document unsupported arches
  + fix make git_ver.h
  + allow xsltproc and w3m calls to fail
  + fix make dist
  + Add a mutt_endwin() before invoking $sendmail
  + Restore setenv function
  + Fix tag-prefix to not abort on $timeout
  + Change km_dokey() to return -2 on a timeout/sigwinch
  + Enable TEXTDOMAINDIR override to make translation testing easier
  + Fix "format string is not a string literal" warnings
- Modifyed and ported patches
  * aw.listreply.diff
  * bsc907453-CVE-2014-9116-jessie.patch
  * bug-676388-largefile.patch
  * mutt-1.5.15-wrapcolumn.diff
  * mutt-1.5.20-sendgroupreplyto.diff
  * mutt-1.5.21-mailcap.diff
  * mutt-1.5.23-carriage-return.path
  * mutt-1.6.1-opennfs.dif
  * patch-1.5.24.vk.pgp_verbose_mime
  * widechar.sidebar.dif
- Delete patch mutt-1.8.2-from4crypt.diff now upstream
- Renamed patch mutt-1.8.2.dif which becomes mutt-1.8.3.dif
* Wed May 10 2017 werner@suse.de
- Add patch mutt-1.8.2-from4crypt.diff
  to fix crash in crypt.c if no From is found or set
* Mon May  1 2017 werner@suse.de
- Switch form TokyoCabinet over to KyotoCabinet
* Sun Apr 30 2017 thorsten.behrens@cib.de
- Remove warning
* Sun Apr 30 2017 thorsten.behrens@cib.de
- Make header cache work again, using TokyoCabinet as backend
- Remove now-obsolete configure parameters
* Sun Apr 30 2017 bwiedemann@suse.com
- call gzip -n to make build more reproducible
* Sat Apr 29 2017 werner@suse.de
- Yet an other package split: now there is a mutt-lang
* Sat Apr 29 2017 werner@suse.de
- Provide a hint on the package split
* Fri Apr 28 2017 werner@suse.de
- Move some extend documentation about mutt in a seperate package
- Remove mutt-1.5.21.de.po as mutt now have a de.po as well
* Fri Apr 28 2017 werner@suse.de
- Update to neomutt 20170421 which updates to mutt 1.8.2
  1.8.2 Bug fix release.
  1.8.1 Bug fix release.
  1.8.0
  - $locale has been removed.  Mutt now respects the LC_TIME setting
    instead.  See also $attribution_locale.
  + $attribution_locale can be used to override the date formatting in
    attribution strings.  When unset, Mutt will use the locale
    environment, but note the default value of $date_format has a
    leading '!' which says to use the C-locale.
  ! Message-id and mail-followup-to headers are now preserved for recalled
    messages.
  + <unsidebar_whitelist> added to complement <sidebar_whitelist>.
  ! The pager position is reset to the top when toggling header-weed.
  ! IMAP messages moved to $trash via server-side copy are marked as read.
  + <root-message> jumps to the root message of a thread.
  ! Piped text attachments are charset converted.
  + Added %%F to $attach_format, to show the content-disposition filename.
    %%d will fall back to %%F which will fall back to %%f.
  + <rename-attachment> allows an attachment name to be changed, without
    modifying the underlying file's name.
  ! Mutt will look for the user's muttrc additionally in
    $XDG_CONFIG_HOME/mutt/.
  + Compressed mbox and mmdf files are now supported via open-hook,
    close-hook, and append-hook.  See contrib/sample.muttrc-compress
    for suggested settings.  Note this is a compile-time option:
  - -enable-compressed.
  + When $flag_safe is set, flagged messages cannot be deleted.
  + The '@' pattern modifier can be used to limit matches to known aliases.
  + <mark-message> creates a hotkey binding to a specific message.  The hotkey
    prefix is specified via $mark_macro_prefix.
  + <setenv> and <unsetenv> can be used to add/remove environment variables
    passed to children.
  ! Mutt will now use the built-in OpenSSL SSL_set_verify() callback
    to verify certificates.  This allows better support for verifying
    chains, including alternative chain support.
  + $uncollapse_new controls whether a thread will be uncollapsed when a new
    message arrives.
  ! $to_chars and $status_chars now accept multibyte characters.
  + <subjectrx> allows replacing matching subjects with something else.
    This can be used to declutter subject lines in the index.
  + <edit-label> can be used to add, change, or delete a message's X-Label.
  ! Pattern expressions with ~y support label tab completion.
  + The header cache now also supports Kyoto Cabinet and LMDB as
    backend databases.
  1.7.2 (2016-12-04):
  ! Bug fix release.  No features were modified or added.
  ! Fixes for OpenSSL 1.1.  Versions less than 0.9.6 are no longer supported.
  1.7.1 (2016-10-08):
  ! Bug fix release.  No features were modified or added.
  1.7.0 (2016-08-18):
  ! Improved alignment when using multi-column characters with
    soft-fill (%%*X) and right-justified (%%>X) format strings.
  + The COLUMNS environment variable will be set to the width of the
    pager when invoking display filters.  This can be used in
    copiousoutput mailcap entries to allow their output to match the
    pager width.
  + The sidebar patch has been merged.  Please watch for airborne
    bovine.  See the documentation for all the options, or simply
    enable it with 'set sidebar_visible'.
  + $mail_check_stats and $mail_check_stats_interval control whether,
    and how often, to scan for unread, flagged, and total message
    counts when checking for new mail in mailboxes.  These statistics
    can be displayed in the sidebar and browser.
  + $trash, when set, specifies the path of the folder where mails
    marked for deletion will be moved, instead of being irremediably
    purged.
  + The <purge-message> function can be used to delete an entry and
    bypass the trash folder.
  + $folder_format has new format strings %%m and %%n, to display
    total and unread message counts for mailboxes.  Note that
    $mail_check_stats should be enabled to use these.
  ! When browsing IMAP, %%N will now display 'N', instead of the unread
    message count.  Please use %%n to display unread messages.
- Removed obsolete patches
  * COLS-workaround.dif
  * mutt-1.6.2-gpgme_set_sender.patch
- Modifyed and ported patches
  * aw.listreply.diff
  * bsc907453-CVE-2014-9116-jessie.patch
  * bug-676388-largefile.patch
  * mutt-1.5.15-wrapcolumn.diff
  * mutt-1.5.20-sendgroupreplyto.diff
  * mutt-1.5.21-mailcap.diff
  * mutt-1.5.23-carriage-return.path
  * mutt-1.5.9i-pgpewrap.diff
  * mutt-1.6.1-opennfs.dif
  * patch-1.5.24.vk.pgp_verbose_mime
  * widechar.sidebar.dif
- Renamed patch
  * mutt-1.6.2.dif becomes mutt-1.8.2.dif
* Mon Mar  6 2017 werner@suse.de
- Explicite add package documentation directory to file list
* Thu Mar  2 2017 werner@suse.de
- Also now recommend urlscan
* Wed Nov 23 2016 werner@suse.de
- Add patch mutt-1.6.2-gpgme_set_sender.patch
  that is avoid name space clash with gpgme_set_sender() from gpgme
* Wed Nov 23 2016 werner@suse.de
- Rename patch mutt-1.5.23-cariage-return.path to
  mutt-1.5.23-carriage-return.path
- Extend patch mutt-1.5.23-carriage-return.path
  Be sure that also signed messages from Android can be verified
  by gpgme interface of mutt
* Tue Sep 13 2016 werner@suse.de
- Update to neomutt 20160826
  Build:
    Disable fmemopen until bug is fixed
  Contrib:
    Keybase portability improvements Joshua Jordi (@JakkinStewart)
    Keybase Integration - Joshua Jordi (@JakkinStewart)
  Bug Fixes:
    Fix notmuch crash toggling virtual folders
    Fix display of pager index when sidebar toggled
    Sidebar's inbox occasionally shows zero/wrong value
    Fix crash opening a second compressed mailbox
  Config:
    Look for /etc/NeoMuttrc and ~/.neomuttrc
  Docs:
    Fix broken links, typos
    Update project link
    Fix version string in the manual
* Tue Jul 26 2016 werner@suse.de
- Update to mutt version 1.6.2 (2016-07-01):
  * send.c: Check $pgp_autoinline and $pgp_replyinline if oppenc is set.
    (closes #3846)
  * The first oppenc call takes place after the initial checks of
    $pgp_autoline and $pgp_replyinline, and doesn't go through the pgp
    menu.
  * Therefore, check for $pgp_autoline and $pgp_replyinline if oppenc is
    set too, to avoid oppenc enabling encryption without INLINE being
    set in those cases.
  * a6a4d6ed0f19 previously cleaned things up so that it is safe to set
    INLINE even if encryption isn't enabled.
  * keymap.c: Fix infinite loop when help is bound to a named key
    combination.
  * Commit a07e8215a0ef introduced a bug in km_error_key, which is
    called when an unbound key is pressed.
  * If help is bound to a sequence containing named keys (e.g. <esc>),
    the raw (untokenized) string would be pushed back into the unget
    buffer. This could lead to an infinite loop of unbound key presses
    triggering more unbound keys being put into the unget buffer.
  * Change km_error_key to tokenize the string before putting it in the
    unget buffer.
  * Much thanks to Jiri Bohac for his bug report, analysis, and initial
    patch!
- Update to neomutt 20160723
  New Features
    New Mail Command - Execute a command on receipt of new mail
    vim-keybindings - Mutt config for vim users
    LMDB - In-memory header caching database
    SMIME Encrypt to Self - Secure storage of sensitive email
  Bug Fixes
    rework mutt_draw_statusline()
    fix cursor position after sidebar redraw
    Add sidebar_format flag ‘%%n’ to display ‘N’ on new mail.
    fix index_format truncation problem
    Fix compiler warnings due to always true condition
    Change sidebar next/prev-new to look at buffy->new too.
    Change the default for sidebar_format to use %%n.
    sidebar “unsorted” order to match Buffy list order.
    Include ncurses tinfo library if found.
    Sidebar width problem
    sidebar crash for non-existent mailbox
    Temporary compatibility workaround
    Reset buffy->new for the current mailbox in IMAP.
    version.sh regression
    crash when notmuch tries to read a message (boo#986534)
    status line wrapping
- Modify patches
  * COLS-workaround.dif
  * aw.listreply.diff
  * bug-676388-largefile.patch
  * mutt-1.5.15-wrapcolumn.diff
  * mutt-1.5.20-sendgroupreplyto.diff
  * mutt-1.5.21-mailcap.diff
  * mutt-1.6.1-opennfs.dif
  * patch-1.5.24.vk.pgp_verbose_mime
  * widechar.sidebar.dif
- Rename patch mutt-1.6.1.dif to mutt-1.6.2.dif
- Delete patch mutt-1.5.21-tinfo.dif
* Mon Jun 13 2016 werner@suse.de
- Update to neomutt 20160611
  - Temporarily disable $sidebar_refresh_time
    Unfortunately, this was causing too many problems.
    It will be fixed and re-enabled as soon as possible.
  - Fix several crashes, on startup, in Keywords
  - Reflow text now works as it should
  - Lots of typos fixed
  - Compress config bug prevented it working
  - Some minor bug-fixes from mutt/default
  - Single quote at line beginning misinterpreted by groff
  - Setting $sidebar_width to more than 128 would cause bad things to happen.
  - Fix alignment in the compose menu.
  - Fix sidebar buffy stats updating on mailbox close.
- Modify patch mutt-1.6.1.dif, that is skip upstream of neo as now
  part of neo
- Adopt patches COLS-workaround.dif, aw.listreply.diff,
  bug-676388-largefile.patch, mutt-1.5.21-tinfo.dif,
  mutt-1.6.1-opennfs.dif, and patch-1.5.24.vk.pgp_verbose_mime
* Thu Jun  2 2016 werner@suse.de
- Yet an other crash due keywords.patch (boo#982129)
* Wed Jun  1 2016 werner@suse.de
- Fix crash due keywords.patch which stumble over not existing
  standard mailbox (boo#982129)
* Tue May 31 2016 werner@suse.de
- Update to neomutt 20160530
- Avoid sidebar patch from bother other users (boo#982129)
- Remove patch patch-1.6.1.rr.compressed.bz2 as now part of neumutt
* Fri May 20 2016 werner@suse.de
- Enable some of the new patches like sidebar (boo#980830)
- Add patch COLS-workaround.dif which should become removed once
  the sidebar patch does not modify COLS anymore
* Thu May 12 2016 werner@suse.de
- Update to mutt version 1.6.1 (2016-05-01):
  ! Bug fix release.  No features were modified or added.
- Add and use neomutt-patches-20160502.tar.gz from
  http://www.neomutt.org/
- Modify the patches
  aw.listreply.diff
  bsc907453-CVE-2014-9116-jessie.patch
  bug-676388-largefile.patch
  mutt-1.5.15-wrapcolumn.diff
  mutt-1.5.20-sendgroupreplyto.diff
  mutt-1.5.21-mailcap.diff
  mutt-1.5.21-tinfo.dif
  mutt-1.5.23-cariage-return.path
  mutt-1.5.9i-pgpewrap.diff
  patch-1.5.24.vk.pgp_verbose_mime
  widechar.sidebar.dif
- Modify and rename the patches
  mutt-1.6.0-opennfs.dif becomes mutt-1.6.1-opennfs.dif
  mutt-1.6.0.dif becomes mutt-1.6.1.dif
  patch-1.6.0.rr.compressed.bz2 becomes patch-1.6.1.rr.compressed.bz2
- Remove the patches
  patch-1.6.0.sidebar.20160411.patch
  nion.sidebar-color.diff
  now upstream or part of neomutt patch collection
* Mon Apr 11 2016 werner@suse.de
- Update to mutt version 1.6.0 (2016-04-04):
  + Enabled utf-8 mailbox support for IMAP.
  + New expandos %%r and %%R for comma separated list of To: and Cc:
    recipients respectively.
  + Improved support for internationalized email and SMTPUTF8 (RFC653[0-3]).
  ! $use_idn has been renamed to $idn_decode.
  + $idn_encode controls whether outgoing email address domains will
    be IDNA encoded.  If your MTA supports it, unset to use utf-8
    email address domains.
  + The S/MIME message digest algorithm is now specified using the
    option $smime_sign_digest_alg.  Note that $smime_sign_command
    should be modified to include "-md %%d".  Please see
    contrib/smime.rc.
  + $reflow_space_quotes allows format=flowed email quotes to be
    displayed with spacing between them.
  ! multipart draft files are now supported.
  + The "-E" command line argument causes mutt to edit draft or include files.
    All changes made in mutt will be saved back out to those files.
  + $resume_draft_files and $resume_edited_draft_files control how
    mutt processes draft files.
  + For classic gpg mode, $pgp_decryption_okay should be set to verify
    multipart/encrypted are actually encrypted.  Please see
    contrib/gpg.rc for the suggested value.
  ! mailto URL header parameters by default are now restricted to
    'body' and 'subject'.
  + mailto_allow and unmailto_allow can be used to add or remove
    allowed mailto header parameters.
  ! The method of setting $hostname has been changed.  Rather than
    scanning /etc/resolv.conf, the domain will now be determined using
    DNS calls.
- Modfied patches
  aw.listreply.diff
  patch-1.5.24.vk.pgp_verbose_mime
- Ported patches
  mutt-1.5.24.dif becomes mutt-1.6.0.dif
  mutt-1.5.24-opennfs.dif becomes mutt-1.6.0-opennfs.dif
  patch-1.5.24.rr.compressed.bz2 becomes patch-1.6.0.rr.compressed.bz2
  patch-1.5.24.sidebar.20151111.patch becomes patch-1.6.0.sidebar.20160411.patch
* Mon Feb 29 2016 werner@suse.de
- Add perl(Expect) as requirement for mutt due to the fact that a
  useful helper script below the samples depends on this (boo#968699)
* Tue Jan 12 2016 vmiklos@collabora.co.uk
- Fix patch-1.5.24.sidebar.20151111.patch to shorten
  imaps://imap.example.com/INBOX correctly to INBOX, not to NBOX. (boo#961470)
* Tue Dec 22 2015 vmiklos@collabora.co.uk
- Update patch-1.5.24.sidebar.20140412.patch to
  patch-1.5.24.sidebar.20151111.patch
  + Updated patch for pristine mutt-1.5.24 source package.
  + Corrected the version info in PATCHES for mutt-1.5.24 and added two small
    patches courtesy of mutt user flatcap. The patch makes %%S optional in
    sidebar_format_str and the other patch fixes a problem with viewing an imap
    folder that gets deleted by another user which causes a mutt crash.
- Modified patches
  + aw.listreply.diff
  + nion.sidebar-color.diff
  + patch-1.5.24.vk.pgp_verbose_mime
  + widechar.sidebar.dif
* Fri Sep 11 2015 werner@suse.de
- Update to mutt version 1.5.24
  + terminal status-line (TS) support, a.k.a. xterm title. see the
  following variables: $ts_enabled, $ts_icon_format, $ts_status_format
  ! $ssl_use_sslv3 is disabled by default.
  ! command-line arguments: -H now combines template and command-line
  address arguments.
  ! GnuPG signature name is set to signature.asc
  + New color object "prompt" added.
  + Ability to encrypt postponed messages.  See $postpone_encrypt and
  $postpone_encrypt_as.
  ! History ring now has a scratch buffer.
  ! mail-key is implemented for GPGME.  (Requires a recent GPGME).
  ! Removed GPG_AGENT_INFO check for GnuPG 2.1 compatibility.  Please
  set pgp_use_gpg_agent if using GnuPG 2.1 or later.
  ! $smime_encrypt_with now defaults to aes256.
  ! GnuPG fingerprints are used internally when possible.
  "--with-fingerprint" should be added to $pgp_list_pubring_command and
  $pgp_list_secring_command to enable this.  Please see contrib/gpg.rc.
  Fingerprints may also be used at the prompts for key selection.
  + $crypt_opportunistic_encrypt automatically enables/disables encryption
  based on message recipients.
  ! Attachments for signed, unencrypted emails may be deleted.
  ! Multiple crypt-hooks may be defined for the same regexp.
  This means multiple keys may be used for a recipient.
  + $crypt_confirmhook allows the confirmation prompt for crypt-hooks to
  be disabled.
  + $ssl_ciphers allows the SSL ciphers to be directly set.
  ! sime_keys better handles importing certificate chains.
  ! sime_keys now records certificate purposes (sign/encrypt).  Run
  "sime_keys refresh" to update smime index files.
  + $maildir_check_cur polls the maildir "cur" directory for new mail.
- Ported patches
  patch-1.5.21.vk.pgp_verbose_mime becomes patch-1.5.24.vk.pgp_verbose_mime
  patch-1.5.23.rr.compressed.bz2 becomes patch-1.5.24.rr.compressed.bz2
  patch-1.5.23.sidebar.20140412.patch becomes patch-1.5.24.sidebar.20140412.patch
  mutt-1.5.21-opennfs.dif becomes mutt-1.5.24-opennfs.dif
  mutt-1.5.23.dif becomes mutt-1.5.24.dif
- Modfied patches
  nion.sidebar-color.diff
  widechar.sidebar.dif
- Removed patch
  patch-1.5.23.xtitles.patch
* Mon Jan 26 2015 werner@suse.de
- Update to mutt version 1.5.23 which is a security bugfix release
  as well as add support for TLS 1.1/1.2
- Remove the patches automake-1.12.patch,
  mutt-1.5.20-gpgme_set_locale.patch, and mutt-CVE-2014-0467.patch
- Replace the patches
  patch-1.5.23.rr.compressed.bz2 with patch-1.5.21.rr.compressed.1.bz2
  mutt-1.5.21.sidebar.20120829.patch with patch-1.5.23.sidebar.20140412.patch
  patch-1.5.5.1.nt.xtitles.3.ab.1 with patch-1.5.23.xtitles.patch
  mutt-1.5.21.dif with mutt-1.5.23.dif
- Modify the patches aw.listreply.diff, bug-676388-largefile.patch,
  and bsc907453-CVE-2014-9116-jessie.patch
- Build with PIE
* Thu Dec  4 2014 werner@suse.de
- Add patch bsc907453-CVE-2014-9116-jessie.patch to fix bsc#907453
  CVE-2014-9116: heap-based buffer overflow in mutt_substrdup()
* Tue Nov 18 2014 lnussel@suse.de
- handle text/html by default (bnc#899712)
  that is add patch mutt-1.5.21-mailcap.diff
* Mon Mar 17 2014 meissner@suse.com
- mutt-CVE-2014-0467.patch: fixed a buffer overflow during header display.
  CVE-2014-0467 / bnc#868115
* Mon Aug  5 2013 ro@suse.de
- BuildRequire libgcrpyt-devel instead of libgcrypt for > 12.3
* Wed May 29 2013 werner@suse.de
- Enable mutt to parse e.g. PGP markers with CRLF
* Thu Apr 18 2013 werner@suse.de
- Add widechar.sidebar.dif as workaround: bnc#813498 - mutt crashes
  in fgetwc in text_enriched_handler
* Mon Jan 14 2013 werner@suse.de
- Remove spurious blank line from new patch to make older patch(1)
  also work with this
- Make it build with older products
* Tue Dec 18 2012 aginies@suse.com
- update sidebar to version 20120829
* Tue Sep 18 2012 vmiklos@suse.cz
- Add back lost sidebar color patch.
* Thu Jun 21 2012 asn@cryptomilk.org
- Update sidebar patch.
* Tue May 29 2012 puzel@suse.com
- fix build with automake-1.12
  - add: automake-1.12.patch
* Fri Apr 13 2012 multiple1902@gmail.com
- Added patch automatically add a filename and description to PGP/MIME attachments.
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Nov 24 2011 vmiklos@vmiklos.hu
- Add patch to introduce a new (optional) check when
  replying to messages originating from a mailing list
* Tue Nov 22 2011 werner@suse.de
- Add patch to use libtinfo if available
* Tue Oct 25 2011 vmiklos@vmiklos.hu
- Add patch to be able to specify the color of the sidebar
* Thu Jul  7 2011 werner@suse.de
- Update patch for Mutt Ticket #3288 and check for empty headers
  in mx_update_context() (bnx#704359)
* Mon Jun 20 2011 werner@suse.de
- Add patches for the following Mutt Tickets:
  [#1771]: pipe-mime
  [#2179]: score-match
  [#3240]: imapuser
  [#3261]: readonly-open
  [#3288]: mx_update_context-segfault
  [#3293]: dont-recode-saved-attachments
  [#3300]: gpgme-1.2
  [#3324]: smimekeys-tmpdir
  [#3326]: emptycharset
  [#3335]: thread-segfault
  [#3339]: smime_keys-chaining
  [#3371]: ansi-escape-segfault
  [#3378]: references
  [#3457]: pop3-segfault
  [#3459]: split-fetches
  [#3483]: header-strchr
  [#3496]: no-implicit_autoview-for-text-html
  [#3506]: gnutls-CN-validation
  [#3515]: gnutls-deprecated-set-priority
  [#3516]: gnutls-deprecated-verify-peers
  with ticket #3506 bnc#700648 becomes fixed, with ticket #3496
  the autoview regression for text/html should be fixed.
- Add one line more for sidebar if displayed on top
* Fri Apr 15 2011 werner@suse.de
- Support offsets in 2gig mbox files even on 32bit architectures (bnc#676388)
* Thu Feb  3 2011 ro@suse.de
- buildrequire gdbm-devel also on 11.4 to fix build
* Wed Feb  2 2011 werner@suse.de
- Switch from buildrequires gpgme-devel to libgpgme-devel for 11.4
- Work around missing buildrequires of libgpgme-devel by adding
  libassuan-devel for 11.4
* Mon Jan 31 2011 gber@opensuse.org
- recommend smtp_daemon since mutt has builtin SMTP support
* Mon Jan 31 2011 werner@suse.de
- Fix the orther sidebar patch as it is broken with MALLOC_CHECK=1
  now static buffers are used instead (re)alloced arrays.
* Wed Jan 26 2011 gber@opensuse.org
- fix build by removing Makefiles from contrib
- added missing %%mime_database_post/%%mime_database_postun
* Wed Jan 26 2011 gber@opensuse.org
- modified desktop file so mutt can be used as the default mailto
  handler
* Fri Nov 26 2010 pth@suse.de
- Update and fix the german translation.
- Update all translations so that the user edits the right translation.
* Thu Nov  4 2010 werner@suse.de
- Update to mutt version 1.5.21 which include last three fixes
  * Beside this better support of S/MIME certificates
- Use an other sidebar patch found for OpenBSD
- Update our patches
* Mon May 10 2010 guido+opensuse.org@berhoerster.name
- add proper category to desktop file
* Mon Apr 19 2010 lnussel@suse.de
- fix build against openssl 1.0
* Wed Dec  2 2009 werner@suse.de
- Do not fold From lines into wrong format (bnc#559525)
* Wed Nov 25 2009 werner@suse.de
- Update for bnc#537141: do not add certificates with wrong hosts
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Sep  9 2009 werner@suse.de
- Fix incorrectly handling of \0 character in SSL certificate (bnc#537141)
* Wed Jul 15 2009 werner@suse.de
- Make gpgme work even with locale, patch from Evan McClain
  (bnc#519628)
* Fri Jun 26 2009 werner@suse.de
- Update to mutt version 1.5.20 which include last fix
* Tue Apr 21 2009 werner@suse.de
- Upstream fix to make mutt showing new message count (bnc#487718)
* Tue Mar  3 2009 werner@suse.de
- updated to mutt version 1.5.19 mostly a bugfix release
- updated sidebar patch to 1.5.18.sidebar.20080611
  * make it work with 1.5.19
  * make sidebar-fix also work
- updated compression patch to patch-1.5.19.rr.compressed
- enable smtp support
- enable mixmaster support
- use regex(7) of glibc
* Thu Apr 10 2008 werner@suse.de
- Avoid trouble with krb5-config
* Thu Dec 20 2007 bwalle@suse.de
- updated to mutt version 1.5.17 the bug fix release
- updated sidebar patch to 1.5.17.sidebar.20071102
- updated compression patch to 1.5.17.rr.compressed.1
* Wed Dec  5 2007 ro@suse.de
- moved /etc/skel/.muttrc to this package
* Thu Sep 20 2007 werner@suse.de
- Replace handmade sidebar patch with oringnal one
- Set check_mbox_sizes to make mutt backward compatible (#326697)
- Use imap_force_ssl alias for ssl_force_tls even in 10.3
* Thu Jun 21 2007 werner@suse.de
- Update to mutt version 1.5.16 the bug fix version
* Fri Jun  1 2007 werner@suse.de
- Update to mutt version 1.5.15 due CVE-2007-1558 (bug #279843)
* Wed May 16 2007 werner@suse.de
- Overflow: don't compare signed with unsigned (bug #275069)
* Fri Mar 23 2007 rguenther@suse.de
- add gdbm-devel and ncurses-devel BuildRequires
* Mon Feb 26 2007 stbinner@suse.de
- fix build by including icon and .desktop into package
* Thu Nov 16 2006 werner@suse.de
- Make sidebar fix smarter by not breaking new status (bug #221599)
* Thu Nov  9 2006 werner@suse.de
- Do security check for opening files on NFS file systems (#210159)
- Reenable SASL and GSSAPI
- Make LOGIN work even if SASL is enabled
- Make mutt use ispell again
- Update the sidebar patch
- Avoid reads of mailboxes if no sidebar is enabled (#215261)
* Fri Sep 15 2006 werner@suse.de
- Enable libgpgme (bug #203486)
* Mon Aug 28 2006 werner@suse.de
- Add sidebar patch to mutt to have the mailboxes around
- Make the old variable imap_force_ssl an alias to ssl_force_tls
  for older SuSE distributions
* Thu Aug 17 2006 werner@suse.de
- Update to mutt 1.5.13
  * Various fixes in imap handling
* Mon Jul 17 2006 werner@suse.de
- Update to mutt 1.5.12
  * Include previous security fixes
  * Fix bug in curses handling
  * Better caching of mail bodies
  * Remove memory leaks
* Thu Jun 29 2006 werner@suse.de
- Update to mutt 1.5.11
* Wed Jun 28 2006 werner@suse.de
- Fix mutt IMAP buffer overflow in namespace parsing (bug #188872)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 mmj@suse.de
- Compile with -fstack-protector
* Tue Nov 29 2005 sbrabec@suse.cz
- Don't package icon already present in desktop-data-SuSE.
  Cleans rpm -V output.
* Mon Oct 10 2005 mmj@suse.de
- Readd -fno-strict-aliasing
* Mon Oct  3 2005 mmj@suse.de
- Signatures with no newline should not cause mutt to think
  it's a changed message [#117451]
* Thu Jul 28 2005 mmj@suse.de
- Add patch to set term window title bar with the mbox name [#98557]
* Sun Jul 24 2005 mmj@suse.de
- Fix segfault with S/Mime [#87177]
* Fri Jul  8 2005 mmj@suse.de
- Remove bogus hunk from imap race fix patch
* Mon Jun 27 2005 mmj@suse.de
- Add patch from Thomas Glanzmann to fix imap crashes
* Mon May  9 2005 mmj@suse.de
- Add patch for wrapcolumn by Manfred Hollstein
* Tue Mar 15 2005 mmj@suse.de
- Update to 1.5.9
* Mon Feb 28 2005 mmj@suse.de
- Make sure a pointer is not NULL before we start referencing it
* Mon Feb 14 2005 mmj@suse.de
- Update to 1.5.8
* Fri Feb 11 2005 mmj@suse.de
- Disable inode sort due to recommendations from the header
  cache developer
* Fri Feb  4 2005 mmj@suse.de
- Update header cache patch and fix build in PLUS
* Wed Feb  2 2005 mmj@suse.de
- Rename mmdf.5 -> mmdf_mutt.5 to not conflict with tin
* Tue Feb  1 2005 mmj@suse.de
- Update to 1.5.7
* Tue Jan 11 2005 mmj@suse.de
- Fix plain auth for sasl with patch from HEAD [#49573]
- Update header cache patch to latest
* Wed Nov 17 2004 mmj@suse.de
- Package pixmaps
* Sat Oct 23 2004 mmj@suse.de
- Switch heimdal-* to kerberos-devel-packages in #nfb as pr. requst
  of Mr. Carsten Höger
* Tue Aug 31 2004 mmj@suse.de
- Update to a new version with bugfixes of the header cache patch
* Wed Aug 18 2004 mmj@suse.de
- Apply a new version of the header cache patch that also supports
  IMAP.
* Fri Jul  2 2004 mmj@suse.de
- Using upstream fix for problem with stat() on source files
  which could contain extra chars such as pipe [#42658]
* Sat Jun  5 2004 mmj@suse.de
- Enable idn support [#41456]
* Thu May 13 2004 mmj@suse.de
- Add maildir header cache patch from
  Thomas Glanzmann <sithglan@stud.uni-erlangen.de>
- Don't remove buildroot in %%install
- Don't strip when installing
* Wed Apr 21 2004 mmj@suse.de
- When requiring postfix, don't install sendmail
* Thu Apr 15 2004 mmj@suse.de
- Add the contrib/ directory to the documentation [#38955]
* Fri Mar 26 2004 mmj@suse.de
- Add # postfix to neededforbuild
* Mon Feb 16 2004 mmj@suse.de
- People are going to ask over and over again about the alternates
  error, even though it's documented in the manual page, so install
  /usr/share/doc/packages/mutt/README.alternates
* Wed Feb  4 2004 mmj@suse.de
- Readd cast that got lost when 99%% of a patch was merged upstream
* Wed Feb  4 2004 mmj@suse.de
- Update to 1.5.6
- Include patch from Joël Riou <joel.riou@normalesup.org> which
  adds a variable config_charset that one may define in a rc file
  that contains non ascii characters (aliases files for
  instance). Where a rc file is sourced, the commands are
  converted from this encoding, so that it works well if you are
  used to working in UTF8 xterms but sometimes have to use a
  latin-encoded terminal.
* Mon Nov 17 2003 mmj@suse.de
- Use rr.compressed for 1.5.5.1 from the author
* Wed Nov  5 2003 mmj@suse.de
- Update to mutt-1.5.5.1i which includes the missing files
* Wed Nov  5 2003 mmj@suse.de
- Update to mutt-1.5.5i which is the last planned development snap-
  shot.
- Remove included/obsoleted patches
- Don't strip explicitly
- For now include snprintf.c and regex.c, they were forgotten in the
  mutt tarball.
* Wed Oct 15 2003 mmj@suse.de
- Don't build as root
- Cleanup specfile a bit
* Thu Sep 18 2003 mmj@suse.de
- Fix head syntax [#31228]
* Tue Sep  9 2003 pthomas@suse.de
- Fix for real :(
* Tue Sep  9 2003 pthomas@suse.de
- Fix the type-punning patch.
* Thu Sep  4 2003 sndirsch@suse.de
- fixed attaching signature; ".signature" must be "~/.signature"
* Sat Aug 16 2003 adrian@suse.de
- install desktop file from kappfinder
* Fri Aug 15 2003 ro@suse.de
- changed neededforbuild: cyrus-sasl
* Wed Aug 13 2003 pthomas@suse.de
- Fix all cases of (unnecessary) type-punning, thus no need for
  - fno-strict-aliasing.
- Include stdlib.h in lib.h for declaration of exit.
- Fix permissions for mutt-1.4.1i-authsasl.diff
* Wed Aug 13 2003 mmj@suse.de
- Add a better fix from Brendan Cully to fix [#25026]
- Add -fno-strict-aliasing
* Sat Jul 26 2003 kukuk@suse.de
- cryus-sasl2 was renamed to cyrus-sasl
* Wed Jul 16 2003 mmj@suse.de
- Add patch from Brendan Cully to fix DIGEST-MD5 sasl
  authentication. [#25026]
* Wed Jun 11 2003 mmj@suse.de
- Rename mbox.5 to mbox_mutt.5 to avoid conflict with tin
- Use %%find_lang macro
* Mon Jun  2 2003 mmj@suse.de
- Add script from Mike Fabian to handle UTF-8 encodings back and
  forth [#27140]
* Tue May 13 2003 mmj@suse.de
- Use %%defattr
- Package muttbug
* Tue Apr 15 2003 ro@suse.de
- fixed neededforbuild
* Fri Mar 21 2003 mmj@suse.de
- Update to 1.4.1 which primarily fixes the imap/utf7.c buffer-
  overflow.
* Thu Jan 23 2003 mmj@suse.de
- Add --enable-buffy-size which got lost because the maintainer
  kept several versions around
* Thu Jan 23 2003 mmj@suse.de
- Add patch to use sasl2 instead og sasl
* Sun Jan  5 2003 mmj@suse.de
- Below action was not A Good Thing[tm] for all, so made it a
  configure option again.
* Fri Nov 15 2002 mmj@suse.de
- Fold the group reply patch in to always be default behaviour
* Fri Nov  8 2002 mmj@suse.de
- Apply fresh 1.4 compressed folder patch instead of 1.3.99 repatch
* Sat Nov  2 2002 mmj@suse.de
- Better version from ME of longline patch
* Fri Nov  1 2002 mmj@suse.de
- Add patch from Michael Elkins to allow lines > 255 [#16030]
- Make patches have a unique name
- Trim the neededforbuild
* Fri May 31 2002 ro@suse.de
- changed neededforbuild <slang> to <slang slang-devel>
* Fri May 31 2002 mmj@suse.de
- Disabled patches that broke IMAP support.
* Wed May 29 2002 mmj@suse.de
- Updated to the next STABLE Mutt release 1.4, which includes
  improved IMAP and POP support. Better maildir handling,
  improved threading. And lots more, which is better summarized
  on http://www.mutt.org
* Tue May 28 2002 mmj@suse.de
- Added a patch to allow longer lines [Bug #16030]
- Added a patch to allow mailboxes > 2 GB [Bug #16356]
* Tue May 14 2002 mmj@suse.de
- Added a patch from Matthias Eckermann to include the original
  To: field in the new To: when doing group reply, and the boolean
  'send_group_reply_to' is set.
* Fri May  3 2002 mmj@suse.de
- Update to 1.3.99 which is just bugfix release towards 1.4
* Wed Apr  3 2002 mmj@suse.de
- automake/autoconf fix. Use AC_LIBOBJ instead of LIBOBJS.
* Wed Mar 20 2002 mmj@suse.de
- Fix segfault in pgpewrap when invoked with incorrect arguments.
  Fixes Bug #15213, patch from axboe@
* Wed Mar 13 2002 mmj@suse.de
- Make /etc/Muttrc %%config(noreplace)
* Wed Mar 13 2002 mmj@suse.de
- Updated to 1.3.28
* Sun Feb 24 2002 mmj@suse.de
- Re-added patches known to work very well, but that was left out
  to evaluate vanilla 1.3.27i:
  - Compressed folder support
  - Iconv patch that fixes qp problems in multibyte locales
* Thu Feb 14 2002 schwab@suse.de
- Don't add /usr/include to include search path.
* Mon Feb  4 2002 mmj@suse.de
- Updated to newest beta-release 1.3.27
* Wed Jan  2 2002 poeml@suse.de
- add patch-1.2,3.rfc822_terminate.1 which fixes a remote
  exploitable string buffer overflow
  (minus hunks #8 and #10 which are already in 1.3.22.1)
* Tue Sep 18 2001 bjacke@suse.de
- fix a possible segfault for a certain search pattern
- fix a possible crash scenario when using gpg and attachments
* Tue Sep  4 2001 bjacke@suse.de
- fix some memory leaks in imap code
- fix bug where non-regular files could be attached
- po updates
* Sat Sep  1 2001 bjacke@suse.de
- update to 1.3.22.1
* Thu Aug 23 2001 bjacke@suse.de
- update to 1.3.21 which fixes some MH bugs and others
* Mon Aug 13 2001 ro@suse.de
- changed neededforbuild <sp_libs> to <sp-devel>
* Thu Jul 26 2001 bjacke@suse.de
- update to 1.3.20
- patched to speed up mbox-sort from n^2 to n*log(n)
* Sat Apr 28 2001 bjacke@suse.de
- another l10n fix
- save manuals gzipped
* Wed Apr 25 2001 mfabian@suse.de
- remove "fuzzy" in header of ja.po. When the header is marked
  as "fuzzy", the charset will not be written to the .mo file
  and mutt will not show Japanese messages correctly.
- don't convert string received from gettext again, the new
  version of gettext already does the conversion to the charset
  of the current locale.
* Thu Apr 19 2001 bjacke@suse.de
- fixed a buffer underrun
- fixed possible segfault (#6979)
- redisabled buffy fix
* Sun Mar 25 2001 bjacke@suse.de
- update to 1.3.16i
- dropped superfluous additional options patch
- add compressed folder patch
- activated buffy fix to circumvent recent NFS a-time problems
* Wed Jan 31 2001 bjacke@suse.de
- fixed version in specfile
* Thu Jan 25 2001 bjacke@suse.de
- dropped tmp patch wich did more bad than good
* Wed Jan 10 2001 bjacke@suse.de
- fixed latest fix
* Tue Jan  9 2001 bjacke@suse.de
- applied tmp file patch
- added smtp_daemon to requires
* Mon Dec 18 2000 bjacke@suse.de
- merged muttssl and mutt
* Mon Dec 11 2000 bjacke@suse.de
- enable fcntl and disable flock locking
* Tue Nov 28 2000 bjacke@suse.de
- update to 1.3.12i due to glibc 2.2 locale issues
- fixed neededforbuild (bug 4254)
- minor specfile changes
* Mon Sep  4 2000 vinil@suse.cz
- czech po file corrected
* Mon Jul 31 2000 werner@suse.de
- Update to 1.2.5i due bug fixes (IMAP, SIGSEGV in curs_main.c)
* Fri Jul  7 2000 werner@suse.de
- Update to 1.2.4i due to fixes (IMAP, SSL, ...) done in 1.2.3
  and 1.2.4
* Thu Jun 29 2000 werner@suse.de
- Split spec of mutt and muttssl to avoid conflicts during build
- Use different build root to avoid mixed versions
- Update to 1.2.2i to avoid bugs in SSL code, core dumps, and
  mailbox corruption
* Mon May 15 2000 werner@suse.de
- Update to new version 1.2i
  * move changes to 1.2i
  * enable SSL for imap
  * add *.rc from contrib path to doc (samples for pgp using)
- Split mutt into mutt and muttssl
* Wed Mar  8 2000 werner@suse.de
- Disable --enable-exact-address because it fools the users by
  asking questions for nothing.
* Tue Feb 22 2000 werner@suse.de
- Fix programming bug: ncurses now does what the docu says.
  Therefore use_default_color() should be called only once
  after start_color().
* Tue Jan 25 2000 werner@suse.de
- New version 1.0.1i with some minor bug fixes
* Tue Jan 25 2000 kasal@suse.de
- urlview moved to a new package
* Tue Jan 18 2000 werner@suse.de
- /usr/man -> /usr/share/man
- target is ${RPM_ARCH}-suse-linux and nothing more
* Tue Jan 18 2000 werner@suse.de
- New mutt version 1.0i
  * patch for two letter year (e.g. 00)
- New urlview version
  * A SuSE url_handler.sh script
  * A SuSE urlview.conf
* Mon Oct 18 1999 garloff@suse.de
- highlight_unread sometimes didn't work. Fixed.
* Thu Oct 14 1999 garloff@suse.de
- Added contrib/Pine.rc and Mush.rc to as %%docs
* Wed Oct 13 1999 garloff@suse.de
- Two new options: "delete_tilde" and "highlight_unread".
  The meaning is obvious ...
* Fri Oct  1 1999 werner@suse.de
- Added gpg in neededforbuild to get both pgp and gpg
  path included into mutt.
* Tue Sep 28 1999 werner@suse.de
- Put urlview into mutt package
- Use changes Muttrc instead of my.Muttrc
  * there is no variable web_browser anymore
- Require ispell to get spell feature
- A few sample muttrc and urlview(rc) for aaa_skel
* Tue Sep 28 1999 ro@suse.de
- update to 1.0pre3
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jul 20 1999 florian@suse.de
- update to 0.95.6i
* Wed Apr 14 1999 ro@suse.de
- use gettext in neededforbuilt (builtin won't work)
* Tue Apr  6 1999 ro@suse.de
- update to 0.95.4i
* Thu Dec  3 1998 bs@suse.de
- added sp and sp_libs to neededforbuild
* Wed Dec  2 1998 bs@suse.de
- use sgmtools instead of linuxdoc for build
* Wed Jul 29 1998 florian@suse.de
- add security patch
* Sun Jul 19 1998 florian@suse.de
- update to version 0.93.1i
* Thu Feb  5 1998 florian@suse.de
- update to version 0.89.1
* Thu Oct  9 1997 florian@suse.de
- update to version 0.85
* Tue May 20 1997 florian@suse.de
- update to version 0.74
* Sun Apr 13 1997 florian@suse.de
- update to new version 0.69
* Tue Jan 28 1997 florian@suse.de
- update to new version 0.59
- pgp-support is enabled
* Thu Jan  2 1997 florian@suse.de
- update to version 0.52
* Thu Jan  2 1997 florian@suse.de
- update to version 0.51
* Thu Jan  2 1997 florian@suse.de
- update to version 0.50
* Thu Jan  2 1997 florian@suse.de
- update to version 0.49
* Thu Jan  2 1997 florian@suse.de
- Neue Version 0.48.1 mit vielen Veraenderungen.
- Anpassungen fuer eine korrekte Host-Absenderadresse.
- Umstieg auf non-sgid-mail spool-Verzeichnis.
* Thu Jan  2 1997 florian@suse.de
- update to newer version
  Mon Sep  2 03:06:07 MET DST 1996
  new version.
